.. Django Kubernetes Manager documentation master file, created by
   sphinx-quickstart on Tue Mar 10 17:28:38 2020.

.. image:: https://circleci.com/gh/IntrospectData/django-kubernetes-manager.svg?style=shield
   :target: https://circleci.com/gh/IntrospectData/django-kubernetes-manager


.. image:: https://api.codeclimate.com/v1/badges/c866017f9bd481a3c9ca/maintainability
   :target: https://codeclimate.com/github/IntrospectData/django-kubernetes-manager/maintainability
   :alt: Maintainability


.. image:: https://api.codeclimate.com/v1/badges/c866017f9bd481a3c9ca/test_coverage
   :target: https://codeclimate.com/github/IntrospectData/django-kubernetes-manager/test_coverage
   :alt: Test Coverage

.. image:: dkm-logo.png
   :width: 500
   :alt: DjangoKubernetesManager

Welcome to Django Kubernetes Manager's documentation!
=====================================================
Django Kubernetes Manager is an open source project to wrap the complexity of Kubernetes management in the simplicity of Django Rest Framework.

Documentation is (mostly) autogenerated, so if you notice anything that should be changed or added, please `create a PR`_  🙋

.. _`create a PR`: https://github.com/introspectdata/django-kubernetes-manager/pulls


Introduction
-------------

Our engineering team has developed several data processing apps, and
found celery wasn't quite enough for dispatching heavier tasks.
We decided to try Kubernetes Jobs, and while pleased with performance,
wanted a less verbose, more object oriented way to interact with our clusters.

And thus Django Kubernetes Manager was spawned. Using Django Rest Framework and
the kubernetes client library, our devs came up with the idea to treat each object
we'd be deploying as a Model instance, and use the DRF viewsets and actions to
create an RESTful API framework from which we could extend for each projects
particular needs.


Table of Contents
====================
.. toctree::
   :maxdepth: 3

   getting_started
   models
   serializers
   views
   utils
   api

Indices and tables
==================
* :ref:`genindex`
* :ref:`modindex`
* :ref:`search`
